@@ -2,13 +2,13 @@ package Text::Reform;
 
 use strict; use vars qw($VERSION @ISA @EXPORT @EXPORT_OK); use Carp;
 use 5.005;
-use version; $VERSION = qv('1.12.2');
+$VERSION = '1.07';
 
 require Exporter;
 
 @ISA = qw(Exporter);
 @EXPORT = qw( form );
-@EXPORT_OK = qw( columns tag break_with break_at break_wrap break_TeX debug );
+@EXPORT_OK = qw( tag break_with break_wrap break_TeX );
 
 my @bspecials = qw( [ | ] );
 my @lspecials = qw( < ^ > );
@@ -25,6 +25,7 @@ my $emptyref = '';
 sub import
 {
 	use POSIX qw( localeconv );
+	$DB::single=1;
 	$decimal = localeconv()->{decimal_point} || '.';
 
 	my $lnumerical = '[>]+(?:'.quotemeta($decimal).'[<]{1,})';
@@ -43,7 +44,7 @@ sub import
 }
 
 sub carpfirst {
-	use vars '%carped';
+	our %carped;
 	my ($msg) = @_;
 	return if $carped{$msg}++;
 	carp $msg;
@@ -68,8 +69,8 @@ sub break_with
 		}
 		else
 		{
-			@ret = (substr($_[0],0,$_[1]-$hylen),
-				substr($_[0],$_[1]-$hylen))
+			@ret = (substr($_[0],0,$_[1]-length($hyphen)),
+				substr($_[0],$_[1]-length($hyphen)))
 		}
 		if ($ret[0] =~ /\A\s*\Z/) { return ("",$_[0]); }
 		else { return ($ret[0].$hyphen,$ret[1]); }
@@ -77,38 +78,6 @@ sub break_with
 
 }
 
-sub break_at {
-	my ($hyphen, $opts_ref) = @_;
-	my $hylen = length($hyphen);
-    my $except = $opts_ref->{except};
-	my @ret;
-	sub
-	{
-		my $max = $_[2]-$hylen;
-		if ($max <= 0) {
-			@ret = (substr($_[0],0,1), substr($_[0],1))
-		}
-        elsif (defined $except && $_[0] =~ m/\A (.{1,$max}) ($except .*)/xms) {
-			@ret = ($1,$2);
-        }
-        elsif (defined $except && $_[0] =~ m/\A ($except) (.*)/xms) {
-			@ret = ($1,$2);
-        }
-		elsif ($_[0] =~ /\A (.{1,$max}$hyphen) (.*)/xms) {
-			@ret = ($1,$2);
-		}
-		elsif (length($_[0])>$_[2]) {
-			@ret = (substr($_[0],0,$_[1]-$hylen).$hyphen,
-				substr($_[0],$_[1]-$hylen))
-		}
-		else {
-			@ret = ("",$_[0]);
-		}
-		if ($ret[0] =~ /\A\s*\Z/) { return ("",$_[0]); }
-		else { return @ret; }
-	}
-}
-
 sub break_wrap
 {
 	return \&break_wrap unless @_;
@@ -122,7 +91,7 @@ sub break_TeX
 {
 	my $file = $_[0] || "";
 
-	croak "Can't find TeX::Hyphen module"
+	croak "Can't find TeX::Hypen module"
 		unless require "TeX/Hyphen.pm";
 
 	$hyp{$file} = TeX::Hyphen->new($file||undef)
@@ -140,14 +109,12 @@ sub break_TeX
 	}
 }
 
-my $debug = 0;
-sub _debug { print STDERR @_, "\n" if $debug }
-sub debug { $debug = 1; }
+sub debug { print STDERR @_, "\n" if $::DEBUG || $::DEBUG }
 
 sub notempty
 {
 	my $ne = ${$_[0]} =~ /\S/;
-	_debug("\tnotempty('${$_[0]}') = $ne\n");
+	debug("\tnotempty('${$_[0]}') = $ne\n");
 	return $ne;
 }
 
@@ -209,27 +176,21 @@ sub replace($$$$)   # ($fmt, $len, $argref, $config)
 			$ws =~ s/\n/$nonnl? "" : " "/ge if $config->{fill};
 			my $lead = ($config->{squeeze} ? ($ws ? " " : "") : $ws);
 			my $match = $lead . $word;
-			_debug "Extracted [$match]";
 			last if $text && $match =~ /\n/;
 			my $len1 = length($match);
 			if ($len1 <= $rem)
 			{
-				_debug "Accepted [$match]";
 				$text .= $match;
 				$rem  -= $len1;
 				$$ref = $extra;
 			}
 			else
 			{
-				_debug "Need to break [$match]";
-				# was: if ($len1 > $_[1] and $rem-length($lead)>$config->{minbreak})
-				if ($rem-length($lead)>$config->{minbreak})
+				if ($len1 > $_[1] and $rem-length($lead)>$config->{minbreak})
 				{
-					_debug "Trying to break '$match'";
 					my ($broken,$left) =
 						$config->{break}->($match,$rem,$_[1]);	
 					$text .= $broken;
-					_debug "Broke as: [$broken][$left]";
 					$$ref = $left.$extra;
 					$rem -= length $broken;
 				}
@@ -363,7 +324,7 @@ sub fix_config(\%)
 	unless (ref $config->{pagefeed} eq 'CODE')
 		{ my $tmp = $config->{pagefeed}; $config->{pagefeed} = sub { $tmp } }
 	unless (ref $config->{break} eq 'CODE')
-		{ $config->{break} = break_at($config->{break}) }
+		{ $config->{break} = break_with($config->{break}) }
 	if (defined $config->{pagenum} && ref $config->{pagenum} ne 'SCALAR') 
 		{ my $tmp = $config->{pagenum}+0; $config->{pagenum} = \$tmp }
 	unless (ref $config->{filler} eq 'HASH') {
@@ -381,7 +342,7 @@ sub FormOpt::DESTROY
 
 sub form
 {
-	use vars '%carped';
+	our %carped;
 	local %carped;
 	my $config = {%std_config};
 	my $startidx = 0;
@@ -446,10 +407,10 @@ sub form
 		}
 		elsif (!defined eval { local $SIG{__DIE__};
 				       $_[$nextarg] = $next;
-				       _debug "writeable: [$_[$nextarg]]";
+				       debug "writeable: [$_[$nextarg]]";
 				       1})
 		{
-		        _debug "unwriteable: [$_[$nextarg]]";
+		        debug "unwriteable: [$_[$nextarg]]";
 			my $arg = $_[$nextarg];
 			splice @_, $nextarg, 1, \$arg;
 		}
@@ -490,7 +451,7 @@ sub form
 				: ${$_[$startidx++]}||"";
 		}
 		my $format = shift @format_stack;
-		_debug("format: [$format]");
+		debug("format: [$format]");
 	
 		my @parts = split /(\n|(?:\\.)+|$fieldpat)/, $format;
 		push @parts, "\n" unless @parts && $parts[-1] eq "\n";
@@ -505,7 +466,7 @@ sub form
 			{
 				if ($part =~ /\A(?:\\.)+/)
 				{
-					_debug("esc literal: [$part]");
+					debug("esc literal: [$part]");
 					my $tmp = $part;
 					$tmp =~ s/\\(.)/$1/g;
 					$text .= $tmp;
@@ -520,15 +481,15 @@ sub form
 						my $type = $1;
 						$type = 'J' if $part =~ /$ljustified/;
 						croak BAD_CONFIG if ($ref[$startidx] eq 'HASH');
-						_debug("once field: [$part]");
-						_debug("data was: [${$_[$nextarg]}]");
+						debug("once field: [$part]");
+						debug("data was: [${$_[$nextarg]}]");
 						$text .= replace($type,length($part),$_[$nextarg],$config);
-						_debug("data now: [${$_[$nextarg]}]");
+						debug("data now: [${$_[$nextarg]}]");
 					}
 					else
 					{
 						$text .= substr($config->{filler}{left} x length($part), -length($part));
-						_debug("missing once field: [$part]");
+						debug("missing once field: [$part]");
 					}
 					$nextarg++;
 				}
@@ -540,16 +501,16 @@ sub form
 					my $type = $1;
 					$type = 'J' if $part =~ /$bjustified/;
 					croak BAD_CONFIG if ($ref[$startidx] eq 'HASH');
-					_debug("multi field: [$part]");
-					_debug("data was: [${$_[$nextarg]}]");
+					debug("multi field: [$part]");
+					debug("data was: [${$_[$nextarg]}]");
 					$text .= replace($type,length($part),$_[$nextarg],$config);
-					_debug("data now: [${$_[$nextarg]}]");
+					debug("data now: [${$_[$nextarg]}]");
 					push @data, $_[$nextarg];
 					$nextarg++;
 				}
 				else
 				{
-					_debug("literal: [$part]");
+					debug("literal: [$part]");
 					my $tmp = $part;
 					$tmp =~ s/\0(\0*)/$1/g;
 					$text .= $tmp;
@@ -558,7 +519,7 @@ sub form
 						$linecount++;
 						if ($config->{pagelen} && $linecount>=$config->{pagelen})
 						{
-							_debug("\tejecting page:  $config->{pagenum}");
+							debug("\tejecting page:  $config->{pagenum}");
 							carpfirst "\nWarning: could not format page ${$config->{pagenum}} within specified page length"
 								if $^W && $config->{pagelen} && $linecount > $config->{pagelen};
 							${$config->{pagenum}}++;
@@ -578,8 +539,8 @@ sub form
 						}
 					}
 				}
-				_debug("\tnextarg now:  $nextarg");
-				_debug("\tstartidx now: $startidx");
+				debug("\tnextarg now:  $nextarg");
+				debug("\tstartidx now: $startidx");
 			}
 			$firstline = 0;
 			$filled = ! grep { notempty $_ } @data;
@@ -643,7 +604,7 @@ sub form
                 if ($ref[$i] eq 'ARRAY')
                         { eval { @{$orig[$i]} = map "$_\n", split /\n/, ${$_[$i]} } }
                 elsif (!$ref[$i])
-                        { eval { _debug("restoring $i (".$_[$i].") to " .
+                        { eval { debug("restoring $i (".$_[$i].") to " .
                                  defined($orig[$i]) ? $orig[$i] : "<undef>");
                                  ${$_[$i]} = $orig[$i] } }
         }
@@ -732,8 +693,8 @@ Text::Reform - Manual text wrapping and reformatting
 
 =head1 VERSION
 
-This document describes version 1.11 of Text::Reform,
-released May  7, 2003.
+This document describes version 1.07 of Text::Reform,
+released April  2, 2003.
 
 =head1 SYNOPSIS
 
@@ -775,7 +736,7 @@ A single < is formatted as the literal character '<'
 Right-justified field indicator.
 A series of two or more sequential >'s specify
 a right-justified field to be filled by a subsequent value.
-A single > is formatted as the literal character '>'
+A single < is formatted as the literal character '<'
 
 =item <<<>>>
 
@@ -788,7 +749,7 @@ must be at least 2 '<' and 2 '>'.
 Centre-justified field indicator.
 A series of two or more sequential ^'s specify
 a centred field to be filled by a subsequent value.
-A single ^ is formatted as the literal character '^'
+A single ^ is formatted as the literal character '<'
 
 =item >>>.<<<<
 
@@ -1200,62 +1161,15 @@ which could therefore be rewritten:
              @data;
 
 The subroutine C<Text::Reform::break_with> takes a single string
-argument and returns a reference to a sub which hyphenates by cutting 
-off the text at the right margin and appending the string argument.
-Hence the first of the two examples could be rewritten:
+argument and returns a reference to a sub which hyphenates with that
+string. Hence the first of the two examples could be rewritten:
 
-        use Text::Reform qw( form break_with );
+        use Text::Reform qw( form break_wrap );
 
         form { break => break_with('~') }
              $format_str,
              @data;
 
-The subroutine C<Text::Reform::break_at> takes a single string
-argument and returns a reference to a sub which hyphenates by
-breaking immediately after that string. For example:
-
-        use Text::Reform qw( form break_at );
-
-        form { break => break_at('-') }
-               "[[[[[[[[[[[[[[",
-	       "The Newton-Raphson methodology";
-
-	# returns:
-	#
-	#       "The Newton-
-	#        Raphson 
-	#        methodology"
-
-Note that this differs from the behaviour of C<break_with>, which
-would be:
-
-        form { break => break_with('-') }
-               "[[[[[[[[[[[[[[",
-	       "The Newton-Raphson methodology";
-
-	# returns:
-	#
-	#       "The Newton-R-
-	#        aphson metho-
-	#        dology"
-
-Hence C<break_at> is generally a better choice.
-
-C<break_at> also takes an 'except' option, which tells the resulting
-subroutine not to break in the middle of certain strings. For example:
-
-        form { break => break_at('-', {except=>qr/Newton-Raphson/}) }
-               "[[[[[[[[[[[[[[",
-	       "The Newton-Raphson methodology";
-
-	# returns:
-	#
-	#       "The
-    #        Newton-Raphson 
-	#        methodology"
-
-This option is particularly useful for preserving URLs.
-
 The subroutine C<Text::Reform::break_TeX> 
 returns a reference to a sub which hyphenates using 
 Jan Pazdziora's TeX::Hyphen module. For example:
@@ -1872,40 +1786,12 @@ Damian Conway (damian@conway.org)
 
 =head1 BUGS
 
-The module uses C<POSIX::strtod>, which may be broken under certain versions
-of Windows. Applying the WINDOWS_PATCH patch to Reform.pm will replace the
-POSIX function with a copycat subroutine.
-
 There are undoubtedly serious bugs lurking somewhere in code this funky :-)
 Bug reports and other feedback are most welcome.
 
-=head1 LICENCE AND COPYRIGHT
+=head1 COPYRIGHT
 
-Copyright (c) 1997-2007, Damian Conway C<< <DCONWAY@CPAN.org> >>. All rights reserved.
-
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
-
-
-=head1 DISCLAIMER OF WARRANTY
-
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
-OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
-PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
-EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
-ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
-YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
-NECESSARY SERVICING, REPAIR, OR CORRECTION.
-
-IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
-LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
-OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
-THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGES.
+Copyright (c) 1997-2000, Damian Conway. All Rights Reserved.
+This module is free software. It may be used, redistributed
+and/or modified under the terms of the Perl Artistic License
+  (see http://www.perl.com/perl/misc/Artistic.html)
